OutputDestination

Enum OutputDestination 

pub enum OutputDestination {
    MainOutput,
}
Possible output destinations for the sound. By default, it will be sent directly to the main track, but you can send it to custom tracks with optional processing on them instead.

Variants



MainOutput

Send the audio data to the main track (default)